@@ -33,6 +33,7 @@ void advise (char *, char *, ...);
 void ambigsw (char *, struct swit *);
 int atooi(char *);
 char **brkstring (char *, char *, char *);
+int check_charset (char *, int);
 void closefds(int);
 char *concat (char *, ...);
 int context_del (char *);
@@ -45,6 +46,7 @@ char *copy (char *, char *);
 char **copyip (char **, char **);
 void cpydata (int, int, char *, char *);
 void cpydgst (int, int, char *, char *);
+int decode_rfc2047 (char *, char *);
 void discard (FILE *);
 void done (int);
 int fdcompare (int, int);
@@ -84,7 +86,7 @@ char *path(char *, int);
 int peekc(FILE *ib);
 int pidwait (pid_t, int);
 int pidstatus (int, FILE *, char *);
-void print_help (char *, struct swit *);
+void print_help (char *, struct swit *, int);
 void print_sw (char *, struct swit *, char *);
 void print_version (char *);
 void push (void);
@@ -113,10 +115,10 @@ char *snprintb (char *, size_t, unsigned, char *);
 int ssequal (char *, char *);
 int stringdex (char *, char *);
 char *trimcpy (char *);
-int uleq (char *, char *);
 int unputenv (char *);
 int uprf (char *, char *);
 int vfgets (FILE *, char **);
+char *write_charset_8bit (void);
 
 #ifdef RPATHS
 int get_returnpath (char *, char *);
