@@ -33,7 +33,7 @@ gans (char *prompt, struct swit *ansp)
 		*cp++ = i;
 	    }
 	}
-	*cp = 0;
+	*cp = '\0';
 	if (ansbuf[0] == '?' || cp == ansbuf) {
 	    printf ("Options are:\n");
 	    for (ap = ansp; ap->sw; ap++)
