@@ -83,7 +83,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] aliases ...", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version (invo_name);
@@ -218,8 +218,8 @@ print_usr (char *s, int list, int norm)
 	while ((cp = getname (pp))) {
 	    if ((np = getm (cp, NULL, 0, norm, NULL)) == NULL)
 		continue;
-	    if (uleq (mp->m_host, np->m_host)
-		    && uleq (mp->m_mbox, np->m_mbox)) {
+	    if (!strcasecmp (mp->m_host, np->m_host)
+		    && !strcasecmp (mp->m_mbox, np->m_mbox)) {
 		vp = vp ? add (ak->ak_name, add (",", vp))
 		    : getcpy (ak->ak_name);
 		mnfree (np);
