@@ -77,7 +77,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [msgs] [switches]", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -260,7 +260,7 @@ seq_printdebug (struct msgs *mp)
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
 	if (is_selected (mp, msgnum))
 	    printf ("%*d: %s\n", DMAXFOLDER, msgnum,
-		snprintb (buf, 100, (unsigned) mp->msgstats[msgnum],
+		snprintb (buf, 100, (unsigned) mp->msgstats[msgnum - mp->lowoff],
 		seq_bits (mp)));
     }
 }
